#!/bin/bash
#

# build_caendigitizer.sh <product_dir> [tar]

# if this build script complains that it cannot find bzlib.h, 
# you need to install bzip2-devel on Scientific Linux

usage()
{
   echo "USAGE: `basename ${0}` <product_dir> [tar]"
}

# -------------------------------------------------------------------
# shared boilerplate
# -------------------------------------------------------------------

get_this_dir() 
{
    ( cd / ; /bin/pwd -P ) >/dev/null 2>&1
    if (( $? == 0 )); then
      pwd_P_arg="-P"
    fi
    reldir=`dirname ${0}`
    thisdir=`cd ${reldir} && /bin/pwd ${pwd_P_arg}`
}

get_ssibuildshims()
{
    # make sure we can use the setup alias
    if [ -z ${UPS_DIR} ]
    then
       echo "ERROR: please setup ups"
       exit 1
    fi
    source `${UPS_DIR}/bin/ups setup ${SETUP_UPS}`
    
    setup ssibuildshims ${ssibuildshims_version} -z ${product_dir}
    if [ -z ${SSIBUILDSHIMS_DIR} ]
    then
       echo "ERROR: failed to setup ssibuildshims ${ssibuildshims_version}"
       exit 1
    fi
}

run_test()
{
    local test_name=${1}
    echo ""
    cd ${blddir}/test/samples/${test_name} || ssi_die "did not find ${test_name}"
    make 
    if [ -e ./bin/Release/${test_name}.bin ]
    then
    echo "run ${test_name}"
    ./bin/Release/${test_name}.bin
    make clean
    else 
    echo "${test_name} ERROR"
    fi
}

# -------------------------------------------------------------------
# start processing
# -------------------------------------------------------------------

product_dir=${1}
maketar=${2}

if [ -z ${product_dir} ]
then
   echo "ERROR: please specify the local product directory"
   usage
   exit 1
fi

# -------------------------------------------------------------------
# package name and version
# -------------------------------------------------------------------

package=caendigitizer
origpkgver=v2_12_0
pkgver=${origpkgver}
ssibuildshims_version=v1_04_13
pkgdotver=`echo ${origpkgver} | sed -e 's/_/./g' | sed -e 's/^v//'`
pkgtarfile=CAENDigitizer_${pkgdotver}_20181015.tgz

get_this_dir

get_ssibuildshims
 
source define_basics NO_QUAL

if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/lib ]
then
   ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball ${product_dir} ${package} ${pkgver} NO_QUAL
   exit 0
fi

echo "building ${package} for ${OS}-${plat} (flavor ${flvr})"

# -------------------------------------------------------------------
# package dependent stuff goes here
# -------------------------------------------------------------------

mkdir -p ${blddir}
if [ ! -d ${blddir} ]
then
   echo "ERROR: failed to create ${blddir}"
   exit 1
fi

incdir=${product_dir}/${package}/${pkgver}/include
docdir=${product_dir}/${package}/${pkgver}/doc
libdir=${pkgdir}/lib

set -x

cd ${pkgdir}
mkdir  -p ${incdir} ${docdir} ${libdir}  || ssi_die "could not create subdirectories"

cd ${blddir}
tar xf ${tardir}/${pkgtarfile} || ssi_die "unable to unwind ${pkgtarfile}"

cp -p ${blddir}/CAENDigitizer_${pkgdotver}/lib/x86_64/libCAENDigitizer.so.${pkgdotver} ${libdir} || ssi_die "unable to copy libCAENComm.so.${pkgdotver}.0"
cd ${libdir}
ln -sf libCAENDigitizer.so.${pkgdotver} libCAENDigitizer.so || ssi_die "unable to create symbolic link"
cd ${pkgdir}
cp -p ${blddir}/CAENDigitizer_${pkgdotver}/include/* ${incdir}/ || ssi_die "unable to copy headers"
cp -p ${blddir}/CAENDigitizer_${pkgdotver}/*.txt ${docdir}/ || ssi_die "unable to copy txt files"
cp -p ${blddir}/CAENDigitizer_${pkgdotver}/install* ${docdir}/ || ssi_die "unable to copy install scripts"
cp -pr ${blddir}/CAENDigitizer_${pkgdotver}/samples ${pkgdir}/ || ssi_die "unable to copy samples"

# patch sample Makefile
cd ${pkgdir}
patch -b -p0 < ${patchdir}/${package}.patch || ssi_die "${package}.patch failed"

set +x

${SSIBUILDSHIMS_DIR}/bin/declare_product ${product_dir} ${package} ${pkgver} NO_QUAL || ssi_die "declare_product failed"

#-------------------------------------------------------------------
# common bottom stuff
# -------------------------------------------------------------------

# this should not complain
echo "Finished building ${package} ${pkgver}"
setup ${package} ${pkgver} -z ${product_dir} || ssi_die "setup failed"
echo "${package} is installed at ${CAENDIGITIZER_DIR}"

# test
mkdir -p ${blddir}/test
cd ${blddir}/test
cp -pr ${CAENDIGITIZER_FQ_DIR}/samples . || ssi_die "copy of samples directory failed"

run_test ReadoutTest_Digitizer
run_test ReadoutTest_DPP_CI_x720
#run_test ReadoutTest_DPP_PHA_x724
run_test ReadoutTest_DPP_PSD_x720

# this must be last 
if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/lib ]
then
   ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball ${product_dir} ${package} ${pkgver} NO_QUAL
fi

exit 0
